"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("../index");
class ConsoleLogger extends index_1.Logger {
    constructor() {
        super(...arguments);
        this._count = 0;
    }
    normalizeParams() {
        super.normalizeParams();
        if (this._levels.indexOf("CONSOLE") < 0) {
            this._levels.unshift("CONSOLE");
            this._level++;
        }
    }
    _log(level, ...args) {
        this._count++;
        let allArgs = [...args], method = console.log;
        switch (level) {
            case "ERROR":
                method = console.error;
                break;
            case "WARN":
                method = console.warn;
                break;
            case "STACK":
                method = console.trace;
                break;
            case "INFO":
                method = console.info;
                break;
            case "DEBUG":
                method = console.debug;
                break;
            default:
                allArgs.unshift("[" + level + "]");
        }
        // WEBDA_LOG_PREFIX will add a custom prefix (set in environment variable)
        if (process.env.WEBDA_LOG_PREFIX) {
            allArgs.unshift("[" + process.env.WEBDA_LOG_PREFIX + "]");
        }
        method.call(console, ...allArgs);
    }
    getCount() {
        return this._count;
    }
    static getModda() {
        return {
            uuid: "Webda/ConsoleLogger",
            label: "ConsoleLogger",
            description: "Output all everything to the console",
            webcomponents: [],
            logo: "images/icons/none.png",
            configuration: {
                schema: {
                    type: "object",
                    properties: {
                        logLevel: {
                            type: "string",
                            value: "INFO"
                        },
                        logLevels: {
                            type: "string",
                            value: "ERROR,WARN,CONSOLE,INFO,DEBUG"
                        }
                    }
                }
            }
        };
    }
}
exports.ConsoleLogger = ConsoleLogger;
//# sourceMappingURL=consolelogger.js.map